@@ -1,5 +1,5 @@
-#  tests for python-chromedriver-binary-2.46.0-py36_0 (this is a generated file);
-print('===== testing package: python-chromedriver-binary-2.46.0-py36_0 =====');
+#  tests for python-chromedriver-binary-73.0.3683.68.0-py36_0 (this is a generated file);
+print('===== testing package: python-chromedriver-binary-73.0.3683.68.0-py36_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import subprocess
@@ -46,7 +46,7 @@ assert path in os.environ["PATH"], \
     "Path didn't get installed by side-effect: " + os.environ["PATH"]
 #  --- run_test.py (end) ---
 
-print('===== python-chromedriver-binary-2.46.0-py36_0 OK =====');
+print('===== python-chromedriver-binary-73.0.3683.68.0-py36_0 OK =====');
 print("import: 'chromedriver_binary'")
 import chromedriver_binary
 
